@@ -141,38 +141,41 @@ msaenet.tune.ncvreg = function(x, y, family, penalty,
 
     if (tune == 'aic') {
 
-      ics.list = mapply(.aic,
-                        deviance = lapply(simple.model.list, .deviance.ncvreg),
-                        df       = lapply(simple.model.list, .df.ncvreg),
-                        SIMPLIFY = FALSE)
+      ics.list = mapply(
+        .aic,
+        deviance = lapply(simple.model.list, .deviance),
+        df       = lapply(simple.model.list, .df),
+        SIMPLIFY = FALSE)
 
     }
 
     if (tune == 'bic') {
 
-      ics.list = mapply(.bic,
-                        deviance = lapply(simple.model.list, .deviance.ncvreg),
-                        df       = lapply(simple.model.list, .df.ncvreg),
-                        nobs     = lapply(simple.model.list, .nobs.ncvreg),
-                        SIMPLIFY = FALSE)
+      ics.list = mapply(
+        .bic,
+        deviance = lapply(simple.model.list, .deviance),
+        df       = lapply(simple.model.list, .df),
+        nobs     = lapply(simple.model.list, .nobs),
+        SIMPLIFY = FALSE)
 
     }
 
     if (tune == 'ebic') {
 
-      ics.list = mapply(.ebic,
-                        deviance = lapply(simple.model.list, .deviance.ncvreg),
-                        df       = lapply(simple.model.list, .df.ncvreg),
-                        nobs     = lapply(simple.model.list, .nobs.ncvreg),
-                        nvar     = lapply(simple.model.list, .nvar.ncvreg),
-                        gamma    = ebic.gamma,
-                        SIMPLIFY = FALSE)
+      ics.list = mapply(
+        .ebic,
+        deviance = lapply(simple.model.list, .deviance),
+        df       = lapply(simple.model.list, .df),
+        nobs     = lapply(simple.model.list, .nobs),
+        nvar     = lapply(simple.model.list, .nvar),
+        gamma    = ebic.gamma,
+        SIMPLIFY = FALSE)
 
     }
 
     ics = sapply(ics.list, function(x) min(x))
     ics.min.idx = which.min(ics)
-    best.model = simple.model.list[[ics.min.idx]]
+    best.model  = simple.model.list[[ics.min.idx]]
 
     best.gamma  = best.model$'gamma'
     best.alpha  = best.model$'alpha'
@@ -213,20 +216,23 @@ msaenet.tune.nsteps.ncvreg = function(model.list,
   } else {
 
     if (tune.nsteps == 'aic')
-      ics = .aic(deviance  = sapply(model.list, .deviance.ncvreg),
-                 df        = sapply(model.list, .df.ncvreg))
+      ics = .aic(
+        deviance  = sapply(model.list, .deviance),
+        df        = sapply(model.list, .df))
 
     if (tune.nsteps == 'bic')
-      ics = .bic(deviance  = sapply(model.list, .deviance.ncvreg),
-                 df        = sapply(model.list, .df.ncvreg),
-                 nobs      = sapply(model.list, .nobs.ncvreg))
+      ics = .bic(
+        deviance  = sapply(model.list, .deviance),
+        df        = sapply(model.list, .df),
+        nobs      = sapply(model.list, .nobs))
 
     if (tune.nsteps == 'ebic')
-      ics = .ebic(deviance = sapply(model.list, .deviance.ncvreg),
-                  df       = sapply(model.list, .df.ncvreg),
-                  nobs     = sapply(model.list, .nobs.ncvreg),
-                  nvar     = sapply(model.list, .nvar.ncvreg),
-                  gamma    = ebic.gamma.nsteps)
+      ics = .ebic(
+        deviance = sapply(model.list, .deviance),
+        df       = sapply(model.list, .df),
+        nobs     = sapply(model.list, .nobs),
+        nvar     = sapply(model.list, .nvar),
+        gamma    = ebic.gamma.nsteps)
 
     best.step = which.min(ics)
 
@@ -242,13 +248,15 @@ msaenet.tune.nsteps.ncvreg = function(model.list,
                    eps, max.iter, ...) {
 
   if (family == 'cox') {
-    fit = ncvreg::ncvsurv(X = x, y = y, penalty = penalty,
-                          gamma = gamma, alpha = alpha, lambda = lambda,
-                          eps = eps, max.iter = max.iter, ...)
+    fit = ncvreg::ncvsurv(
+      X = x, y = y, penalty = penalty,
+      gamma = gamma, alpha = alpha, lambda = lambda,
+      eps = eps, max.iter = max.iter, ...)
   } else {
-    fit = ncvreg::ncvreg(X = x, y = y, family = family, penalty = penalty,
-                         gamma = gamma, alpha = alpha, lambda = lambda,
-                         eps = eps, max.iter = max.iter, ...)
+    fit = ncvreg::ncvreg(
+      X = x, y = y, family = family, penalty = penalty,
+      gamma = gamma, alpha = alpha, lambda = lambda,
+      eps = eps, max.iter = max.iter, ...)
   }
 
   fit
